from jinja2 import Environment, FileSystemLoader, select_autoescape
import pathlib

def render(template_path, params):
    env = Environment(
        loader=FileSystemLoader(searchpath=pathlib.Path().absolute(), encoding='UTF-8', followlinks=False),
        autoescape=select_autoescape()
    )
    template = env.get_template(template_path)
    return template.render(**params)




class Axes:
    limmits = None
    ticks = None
    labels = None

    def __init__(self, limits=None, ticks=None, labels=None):
        self.limmits = limits
        self.ticks = ticks
        self.labels = labels



from charts.axes import Axes
from charts.series import Series


class IChart:
    title = None
    axes = None
    series = None

    def __init__(self, title="My Chart", axes=None, series=[]):
        self.title = title
        self.axes = axes
        self.series

        assert type(self.title) == str
        assert type(self.axes) == Axes or self.axes == None
        assert type(self.series) == list and (
            len(self.series) == 0 or all([type(s) == Series for s in self.series])
        )

    def render(self):
        raise NotImplementedError
